@@ -2,12 +2,15 @@ import gtk, pygtk, os,sys,time,math,hildon,hildondesktop,dbus,gobject
 from dbus.mainloop.glib import DBusGMainLoop
 lfocus_pid=0
 keyboard_stat=0
-def led_on(event):
-	os.popen("/usr/share/lfocus/v4l2-ctl -c torch_intensity=1")
+y_loc=40
+def led(event):
+	stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
+	os.popen("/usr/share/lfocus/v4l2-ctl -c torch_intensity="+str(int(not(stat))))
 def led_off(event):
 	os.popen("/usr/share/lfocus/v4l2-ctl -c torch_intensity=0")
-def rled_on(event):
-	os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity=3")
+def rled(event):
+	stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
+	os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity="+str(int(not(stat))*3))
 def rled_off(event):
 	os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity=0")
 class lfocusplug(hildondesktop.StatusMenuItem):
@@ -15,20 +18,28 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		hildondesktop.StatusMenuItem.__init__(self)
 		dbus_loop = DBusGMainLoop()
 		self.bus = dbus.SystemBus(mainloop=dbus_loop)
-		self.shutter_button_obj = self.bus.get_object("org.freedesktop.Hal","/org/freedesktop/Hal/devices/platform_cam_shutter")
-		self.shutter_button_iface = dbus.Interface(self.shutter_button_obj, "org.freedesktop.Hal.Device")
+		
+		self.shutter_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_shutter")
+		self.shutter_button_iface = dbus.Interface(self.shutter_button_obj, 	"org.freedesktop.Hal.Device")
 		self.bus.add_signal_receiver(	self.shutter_operaion, 
 						signal_name=None, 
-						dbus_interface= "org.freedesktop.Hal.Device", 
-						bus_name="org.freedesktop.Hal", 
-						path="/org/freedesktop/Hal/devices/platform_cam_shutter")
-		
-		#icon_theme = gtk.icon_theme_get_default()
-		#image = icon_theme.load_icon("lfocus-22", 22, gtk.ICON_LOOKUP_NO_SVG)
-		#self.set_status_area_icon(image)
-		button1 = gtk.Button()
+						dbus_interface=				"org.freedesktop.Hal.Device", 
+						bus_name=				"org.freedesktop.Hal", 
+						path=					"/org/freedesktop/Hal/devices/platform_cam_shutter")
+
+		'''
+		self.prox_sens_obj = self.bus.get_object("org.freedesktop.Hal",		"/org/freedesktop/Hal/devices/platform_proximity")
+		self.prox_sens_iface = dbus.Interface(self.prox_sens_obj,		"org.freedesktop.Hal.Device")
+		self.bus.add_signal_receiver(	self.lfocus_menu, 
+						signal_name=None, 
+						dbus_interface= 			"org.freedesktop.Hal.Device", 
+						bus_name=				"org.freedesktop.Hal", 
+						path=					"/org/freedesktop/Hal/devices/platform_proximity")
+		'''
+
+		button1 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
 		button1.connect("clicked",self.lfocus_menu)
-		button2 = gtk.Button()
+		button2 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
 		button2.connect("clicked",self.changer)
 		image1=gtk.image_new_from_icon_name("lfocus-64", 50)
 		container=gtk.Table(1,2,True)
@@ -42,35 +53,76 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		self.hide_all()
 		
 	def lfocus_menu(self,widget,data=None):
-		self.dialog1=gtk.Dialog("Focus")
+		self.dialog1=gtk.Dialog("Live Focus")
 		self.dialog1.set_size_request(800,50)
-		table = gtk.Table(3, 1, False)
-		self.dialog1.vbox.add(table)
-		button2 = gtk.Button(".......")
-		button2.connect("clicked", self.lfocus_leds)
-		image3=gtk.image_new_from_icon_name("general_clock", 50)
+		contain=gtk.Table(2, 1, False)		
+		table = gtk.Table(3, 2, False)
+		table.set_row_spacings(10)
+		image3=gtk.image_new_from_icon_name("gtk-go-down", 50)
+		button2 = gtk.Button()
+		button2.add(image3)
+		def go_up(se):
+			global y_loc
+			y_loc-=70
+			if y_loc<40:
+				y_loc=40
+			pannable_area.jump_to(0, y_loc)
+		def go_down(args):
+			global y_loc
+			y_loc+=70
+			if y_loc>110:
+				y_loc=110
+			pannable_area.jump_to(0, y_loc)
+		image3=gtk.image_new_from_icon_name("gtk-go-up", 50)
 		button6 = gtk.Button()
-		button6.connect("clicked", self.show_diag)
 		button6.add(image3)
-		table.attach(button6, 1, 2, 0, 1)
-		table.attach(button2, 2, 3, 0, 1)
+		button6.connect("clicked",go_up)
+		button2.connect("clicked",go_down)
+		button3 = gtk.ToggleButton("LED")
+		button4=gtk.ToggleButton("RLED")
+		button5 = gtk.Button()
+		image3=gtk.image_new_from_icon_name("general_clock", 50)
+		button5.add(image3)
+		stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
+		button3.set_active(bool(stat))
+		stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
+		button4.set_active(bool(stat))
+		button3.connect("clicked", led)
+		button4.connect("clicked", rled)
+		button5.connect("clicked", self.show_diag)
+		table.attach(button3, 0, 1, 1, 2)
+		table.attach(button4, 1, 2, 1, 2)
+		table.attach(button5, 2, 3, 1, 2)
+		button5.set_size_request(170,50)
+		button4.set_size_request(170,50)
+		button3.set_size_request(170,50)
 		props = gtk.Adjustment(value=0,lower=0,upper=1023,step_incr=32,page_incr=32);
 		self.sld = gtk.HScale(props)
 		self.sld.set_digits(0)
 		self.sld.set_value(int(os.popen("/usr/share/lfocus/v4l2-ctl -C focus_absolute|awk '{print $2}'").read()))
-		self.sld.set_size_request(680,80)
+		self.sld.set_size_request(500,80)
 		self.sld.set_draw_value(False)
 		self.sld.connect('value-changed', self.set_focus)
-		table.attach(self.sld, 0, 1, 0, 1)
+		table.attach(self.sld, 0, 3, 0, 1)
+		pannable_area = hildon.PannableArea()
+		pannable_area.add_with_viewport(table)
+		pannable_area.set_size_request(550,50)
+		contain.attach(button6, 1, 2, 0, 1)
+		contain.attach(button2, 2, 3, 0, 1)
+		contain.attach(pannable_area, 0, 1, 0, 1)
+		self.dialog1.vbox.add(contain)
 		self.dialog1.show_all()
+		global y_loc
+		pannable_area.jump_to(0, y_loc)
+	'''
 	def lfocus_leds(self,widget,data=None):
 		self.dialog2=gtk.Dialog("LEDs")
 		self.dialog2.set_size_request(800,50)
 		table=gtk.Table(1,4,True)
-		button3 = gtk.Button("LED on")
+		button3 = gtk.ToggleButton("LED")
 		button3.connect("clicked", led_on)
 		table.attach(button3,0,1,0,1)
-		button4=gtk.Button("LED off")
+		button4=gtk.Button("RLED")
 		button4.connect("clicked", led_off)
 		table.attach(button4,1,2,0,1)
 		button3 = gtk.Button("R.LED on")
@@ -81,6 +133,7 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		table.attach(button4,3,4,0,1)
 		self.dialog2.vbox.add(table)
 		self.dialog2.show_all()
+	'''
 	def show_diag(self,*args):
 		def stopwatch(a,b,*args):
 			self.dialog3.hide_all()
@@ -138,7 +191,7 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		else :
 
 			self.show_all()
-
+			self.lfocus_menu()
 	def app_quit(widget, data=None):
    		gtk.main_quit()
 	def set_focus(self,index):
